@@ -1,28 +1,20 @@
 # Copyright (C) 2008 by CPqD
 
-BEGIN { $ENV{PATH} = '/bin:/usr/bin' }
+BEGIN { $ENV{PATH} = '/usr/local/bin:/usr/bin:/bin' }
 
 use strict;
 use warnings;
 use Cwd;
 use File::Temp qw/tempdir/;
-use File::Spec::Functions qw/catfile path rootdir/;
+use File::Spec::Functions qw/catfile path/;
 
 # Make sure the svn messages come in English.
 $ENV{LC_MESSAGES} = 'C';
 
 sub has_svn {
-    my $root = rootdir();
-    my @path = (
-	path(),
-	catfile($root, 'usr', 'local', 'bin'),
-	catfile($root, 'usr', 'bin'),
-	catfile($root, 'bin'),
-    );
-
   CMD:
     for my $cmd (qw/svn svnadmin svnlook/) {
-	for my $path (@path) {
+	for my $path (path()) {
 	    next CMD if -x catfile($path, $cmd);
 	}
 	return 0;
